Welcome to whywork. whywork aims to make sure you don't have to work extra and can get the task done on hand.

To import the module: import whywork as ww

Commands:
```python
ww.ctime() // Current Time + String To Go Along

ww.xtime() // Just Current Time

ww.wait(numOfSeconds) // = time.sleep()

ww.cmd(Command) // Run a CMD command from python

ww.file(Name, Extension) // Makes a new file

ww.ip() // returns IP address

ww.libs() // = pip freeze command

ww.power(Number) // find power of a num

ww.pipget(Package) // = pip install Package

ww.mfact(Num) // Factorial

ww.numvalue(Num1, Num2) // Greater or Less Than

```